@@ -12,16 +12,27 @@ use crate::planning::optimize_server::split_data_url_nodes;
 use crate::planning::projection_pushdown::projection_pushdown;
 use crate::planning::split_domain_data::split_domain_data;
 use crate::planning::stitch::{stitch_specs, CommPlan};
-use crate::planning::stringify_local_datetimes::{
-    stringify_local_datetimes, OutputLocalDatetimesConfig,
-};
+use crate::planning::stringify_local_datetimes::stringify_local_datetimes;
 use crate::spec::chart::ChartSpec;
 
+#[derive(Clone, Debug)]
+pub enum PlannerWarnings {
+    StringifyDatetimeMixedUsage(String),
+}
+
+impl PlannerWarnings {
+    pub fn message(&self) -> String {
+        match &self {
+            PlannerWarnings::StringifyDatetimeMixedUsage(message) => message.clone(),
+        }
+    }
+}
+
 #[derive(Debug, Clone)]
 pub struct PlannerConfig {
     pub split_domain_data: bool,
     pub split_url_data_nodes: bool,
-    pub local_datetimes_config: OutputLocalDatetimesConfig,
+    pub stringify_local_datetimes: bool,
     pub projection_pushdown: bool,
     pub extract_inline_data: bool,
 }
@@ -31,7 +42,7 @@ impl Default for PlannerConfig {
         Self {
             split_domain_data: true,
             split_url_data_nodes: true,
-            local_datetimes_config: Default::default(),
+            stringify_local_datetimes: false,
             projection_pushdown: true,
             extract_inline_data: false,
         }
@@ -42,10 +53,13 @@ pub struct SpecPlan {
     pub server_spec: ChartSpec,
     pub client_spec: ChartSpec,
     pub comm_plan: CommPlan,
+    pub warnings: Vec<PlannerWarnings>,
 }
 
 impl SpecPlan {
     pub fn try_new(full_spec: &ChartSpec, config: &PlannerConfig) -> Result<Self> {
+        let warnings: Vec<PlannerWarnings> = Vec::new();
+
         let mut client_spec = full_spec.clone();
 
         // Attempt to limit the columns produced by each dataset to only include those
@@ -54,10 +68,11 @@ impl SpecPlan {
             projection_pushdown(&mut client_spec)?;
         }
 
-        // Split datasets that contain a mix of supported and unsupported transforms
-        if config.split_domain_data {
-            split_domain_data(&mut client_spec)?;
-        }
+        let domain_dataset_fields = if config.split_domain_data {
+            split_domain_data(&mut client_spec)?
+        } else {
+            Default::default()
+        };
 
         let mut task_scope = client_spec.to_task_scope()?;
 
@@ -68,27 +83,20 @@ impl SpecPlan {
             split_data_url_nodes(&mut server_spec)?;
         }
 
-        match &config.local_datetimes_config {
-            OutputLocalDatetimesConfig::LocalNaiveString => {
-                stringify_local_datetimes(&mut server_spec, &mut client_spec, &comm_plan, &None)?;
-            }
-            OutputLocalDatetimesConfig::TimezoneNaiveString(output_tz) => {
-                stringify_local_datetimes(
-                    &mut server_spec,
-                    &mut client_spec,
-                    &comm_plan,
-                    &Some(output_tz.clone()),
-                )?;
-            }
-            OutputLocalDatetimesConfig::UtcMillis => {
-                // Leave local datetimes as UTC milliseconds
-            }
+        if config.stringify_local_datetimes {
+            stringify_local_datetimes(
+                &mut server_spec,
+                &mut client_spec,
+                &comm_plan,
+                &domain_dataset_fields,
+            )?;
         }
 
         Ok(Self {
             server_spec,
             client_spec,
             comm_plan,
+            warnings,
         })
     }
 }
