@@ -8,6 +8,7 @@
  */
 
 use crate::error::Result;
+use crate::expression::escape::escape_field;
 use crate::proto::gen::tasks::Variable;
 use crate::spec::chart::{ChartSpec, MutChartVisitor};
 use crate::spec::data::DataSpec;
@@ -16,16 +17,20 @@ use crate::spec::scale::{
     ScaleDomainSpec, ScaleSpec, ScaleTypeSpec,
 };
 use crate::spec::transform::aggregate::AggregateOpSpec;
+use crate::task_graph::graph::ScopedVariable;
 use crate::task_graph::scope::TaskScope;
 use itertools::Itertools;
+use std::collections::HashMap;
 
 /// This optimization extracts the intensive data processing from scale.domain.data specifications
 /// into dedicated datasets. Domain calculations can't be entirely evaluated on the server, but
 /// this approach still allows the heavy data processing to happen on the server, and to avoid
 /// serializing the full dataset to send to the client.
-pub fn split_domain_data(spec: &mut ChartSpec) -> Result<()> {
+pub fn split_domain_data(
+    spec: &mut ChartSpec,
+) -> Result<HashMap<ScopedVariable, (ScopedVariable, String)>> {
     let task_scope = spec.to_task_scope()?;
-    let mut visitor = SplitUrlDataNodeVisitor::new(&task_scope);
+    let mut visitor = SplitScaleDomainVisitor::new(&task_scope);
     spec.walk_mut(&mut visitor)?;
     for (scope, data) in visitor.new_datasets {
         if scope.is_empty() {
@@ -36,29 +41,32 @@ pub fn split_domain_data(spec: &mut ChartSpec) -> Result<()> {
         }
     }
 
-    Ok(())
+    Ok(visitor.domain_dataset_fields)
 }
 
 #[derive(Debug, Clone)]
-pub struct SplitUrlDataNodeVisitor<'a> {
+pub struct SplitScaleDomainVisitor<'a> {
     pub task_scope: &'a TaskScope,
     pub new_datasets: Vec<(Vec<u32>, DataSpec)>,
+    pub domain_dataset_fields: HashMap<ScopedVariable, (ScopedVariable, String)>,
 }
 
-impl<'a> SplitUrlDataNodeVisitor<'a> {
+impl<'a> SplitScaleDomainVisitor<'a> {
     pub fn new(task_scope: &'a TaskScope) -> Self {
         Self {
             new_datasets: Vec::new(),
             task_scope,
+            domain_dataset_fields: Default::default(),
         }
     }
 }
 
-impl<'a> MutChartVisitor for SplitUrlDataNodeVisitor<'a> {
+impl<'a> MutChartVisitor for SplitScaleDomainVisitor<'a> {
     fn visit_scale(&mut self, scale: &mut ScaleSpec, scope: &[u32]) -> Result<()> {
         let discrete_scale = scale.type_.clone().unwrap_or_default().is_discrete();
         if let Some(ScaleDomainSpec::FieldReference(field_ref)) = &scale.domain {
             let data_name = field_ref.data.clone();
+            let data_var = (Variable::new_data(&data_name), Vec::from(scope));
             let field_name = &field_ref.field;
 
             // Validate whether we can do anything
@@ -77,6 +85,9 @@ impl<'a> MutChartVisitor for SplitUrlDataNodeVisitor<'a> {
                 "{}_{}_domain_{}{}",
                 data_name, scale.name, field_name, scope_suffix
             );
+            let new_data_var = (Variable::new_data(&new_data_name), Vec::from(scope));
+            self.domain_dataset_fields
+                .insert(new_data_var, (data_var, field_name.clone()));
             let (new_data, new_domain) = if discrete_scale {
                 // Extract sort field and op
                 let (sort_field, sort_op) = if let Some(ScaleDataReferenceSort::Parameters(
@@ -179,8 +190,20 @@ impl<'a> MutChartVisitor for SplitUrlDataNodeVisitor<'a> {
 
                 // Create new domain specification that uses the new dataset
                 let new_domain: ScaleDomainSpec = serde_json::from_value(serde_json::json!([
-                    { "signal": format!("(data('{}')[0] || {{}}).min", new_data_name) },
-                    { "signal": format!("(data('{}')[0] || {{}}).max", new_data_name) }
+                    {
+                        "signal":
+                            format!(
+                                "(data(\"{}\")[0] || {{}}).min",
+                                escape_field(&new_data_name)
+                            )
+                    },
+                    {
+                        "signal":
+                            format!(
+                                "(data(\"{}\")[0] || {{}}).max",
+                                escape_field(&new_data_name)
+                            )
+                    }
                 ]))
                 .unwrap();
 
