@@ -13,21 +13,20 @@ use vegafusion_core::task_graph::task_value::TaskValue;
 
 use crate::task_graph::cache::VegaFusionCache;
 use crate::task_graph::task::TaskCall;
+use crate::task_graph::timezone::RuntimeTzConfig;
 use futures_util::{future, FutureExt};
 use prost::Message as ProstMessage;
 use serde_json::Value;
 use std::convert::{TryFrom, TryInto};
 use std::panic::AssertUnwindSafe;
-use std::str::FromStr;
 use std::sync::Arc;
-use vegafusion_core::data::table::VegaFusionTable;
+use vegafusion_core::data::dataset::VegaFusionDataset;
 use vegafusion_core::planning::plan::{PlannerConfig, SpecPlan};
-use vegafusion_core::planning::stringify_local_datetimes::OutputLocalDatetimesConfig;
 use vegafusion_core::planning::watch::{ExportUpdate, ExportUpdateNamespace};
 use vegafusion_core::proto::gen::errors::error::Errorkind;
 use vegafusion_core::proto::gen::errors::{Error, TaskGraphValueError};
 use vegafusion_core::proto::gen::pretransform::pre_transform_warning::WarningType;
-use vegafusion_core::proto::gen::pretransform::PreTransformWarning;
+use vegafusion_core::proto::gen::pretransform::{PlannerWarning, PreTransformWarning};
 use vegafusion_core::proto::gen::pretransform::{
     PreTransformBrokenInteractivityWarning, PreTransformRequest, PreTransformResponse,
     PreTransformRowLimitWarning, PreTransformUnsupportedWarning,
@@ -38,7 +37,7 @@ use vegafusion_core::proto::gen::services::{
 };
 use vegafusion_core::proto::gen::tasks::{
     task::TaskKind, NodeValueIndex, ResponseTaskValue, TaskGraph, TaskGraphValueResponse,
-    TaskValue as ProtoTaskValue, Variable,
+    TaskValue as ProtoTaskValue, TzConfig, Variable,
 };
 use vegafusion_core::spec::chart::ChartSpec;
 
@@ -60,6 +59,7 @@ impl TaskGraphRuntime {
         &self,
         task_graph: Arc<TaskGraph>,
         node_value_index: &NodeValueIndex,
+        inline_datasets: HashMap<String, VegaFusionDataset>,
     ) -> Result<TaskValue> {
         // We shouldn't panic inside get_or_compute_node_value, but since this may be used
         // in a server context, wrap in catch_unwind just in case.
@@ -67,6 +67,7 @@ impl TaskGraphRuntime {
             task_graph,
             node_value_index.node_index as usize,
             self.cache.clone(),
+            inline_datasets,
         ))
         .catch_unwind()
         .await;
@@ -119,7 +120,7 @@ impl TaskGraphRuntime {
                         Ok(async move {
                             let value = task_graph_runtime
                                 .clone()
-                                .get_node_value(task_graph, node_value_index)
+                                .get_node_value(task_graph, node_value_index, Default::default())
                                 .await?;
 
                             Ok::<_, VegaFusionError>(ResponseTaskValue {
@@ -189,8 +190,8 @@ impl TaskGraphRuntime {
         let inline_datasets = inline_pretransform_datasets
             .iter()
             .map(|inline_dataset| {
-                let table = VegaFusionTable::from_ipc_bytes(&inline_dataset.table)?;
-                Ok((inline_dataset.name.clone(), table))
+                let dataset = VegaFusionDataset::from_table_ipc_bytes(&inline_dataset.table)?;
+                Ok((inline_dataset.name.clone(), dataset))
             })
             .collect::<Result<HashMap<_, _>>>()?;
 
@@ -213,33 +214,32 @@ impl TaskGraphRuntime {
         &self,
         spec: &str,
         local_tz: &str,
-        output_tz: &Option<String>,
+        default_input_tz: &Option<String>,
         row_limit: Option<u32>,
-        inline_datasets: HashMap<String, VegaFusionTable>,
+        inline_datasets: HashMap<String, VegaFusionDataset>,
     ) -> Result<PreTransformResult> {
         let spec: ChartSpec =
             serde_json::from_str(spec).with_context(|| "Failed to parse spec".to_string())?;
 
         // Create spec plan
-        let local_datetimes_config = match output_tz {
-            None => OutputLocalDatetimesConfig::LocalNaiveString,
-            Some(output_tz) => OutputLocalDatetimesConfig::TimezoneNaiveString(output_tz.clone()),
-        };
-
         let plan = SpecPlan::try_new(
             &spec,
             &PlannerConfig {
-                local_datetimes_config,
+                stringify_local_datetimes: true,
                 extract_inline_data: true,
                 ..Default::default()
             },
         )?;
 
         // Create task graph for server spec
+        let tz_config = TzConfig {
+            local_tz: local_tz.to_string(),
+            default_input_tz: default_input_tz.clone(),
+        };
         let task_scope = plan.server_spec.to_task_scope().unwrap();
         let tasks = plan
             .server_spec
-            .to_tasks(local_tz, Some(inline_datasets))
+            .to_tasks(&tz_config, &inline_datasets)
             .unwrap();
         let task_graph = TaskGraph::new(tasks, &task_scope).unwrap();
         let task_graph_mapping = task_graph.build_mapping();
@@ -251,7 +251,11 @@ impl TaskGraphRuntime {
                 .get(var)
                 .unwrap_or_else(|| panic!("Failed to lookup variable '{:?}'", var));
             let value = self
-                .get_node_value(Arc::new(task_graph.clone()), node_index)
+                .get_node_value(
+                    Arc::new(task_graph.clone()),
+                    node_index,
+                    inline_datasets.clone(),
+                )
                 .await
                 .expect("Failed to get node value");
 
@@ -336,6 +340,15 @@ impl TaskGraphRuntime {
             });
         }
 
+        // Add planner warnings
+        for planner_warning in &plan.warnings {
+            warnings.push(PreTransformWarning {
+                warning_type: Some(WarningType::Planner(PlannerWarning {
+                    message: planner_warning.message(),
+                })),
+            });
+        }
+
         // Build result
         let response = PreTransformResult {
             result: Some(pre_transform_result::Result::Response(
@@ -360,6 +373,7 @@ async fn get_or_compute_node_value(
     task_graph: Arc<TaskGraph>,
     node_index: usize,
     cache: VegaFusionCache,
+    inline_datasets: HashMap<String, VegaFusionDataset>,
 ) -> Result<CacheValue> {
     // Get the cache key for requested node
     let node = task_graph.node(node_index).unwrap();
@@ -375,10 +389,10 @@ async fn get_or_compute_node_value(
 
         // Clone task so we can move it to async block
         let task = task.clone();
-        let local_tz = task
-            .local_tz
-            .as_ref()
-            .and_then(|tz| chrono_tz::Tz::from_str(tz).ok());
+        let tz_config = task.tz_config.clone().and_then(|tz_config| {
+            RuntimeTzConfig::try_new(&tz_config.local_tz, &tz_config.default_input_tz).ok()
+        });
+
         let cache_key = node.state_fingerprint;
         let cloned_cache = cache.clone();
 
@@ -390,6 +404,7 @@ async fn get_or_compute_node_value(
                     task_graph.clone(),
                     input_node_index,
                     cloned_cache.clone(),
+                    inline_datasets.clone(),
                 )));
             }
 
@@ -416,7 +431,7 @@ async fn get_or_compute_node_value(
                 })
                 .collect::<Result<Vec<_>>>()?;
 
-            task.eval(&input_values, &local_tz).await
+            task.eval(&input_values, &tz_config, inline_datasets).await
         };
 
         // get or construct from cache
