@@ -15,6 +15,7 @@ pub mod formula;
 pub mod joinaggregate;
 pub mod pipeline;
 pub mod project;
+pub mod stack;
 pub mod timeunit;
 pub mod utils;
 pub mod window;
@@ -52,6 +53,7 @@ pub fn to_transform_trait(tx: &TransformKind) -> &dyn TransformTrait {
         TransformKind::Joinaggregate(tx) => tx,
         TransformKind::Window(tx) => tx,
         TransformKind::Project(tx) => tx,
+        TransformKind::Stack(tx) => tx,
     }
 }
 
